==> DQScriptsDemo_0_2_1.zip: DQScriptsDemo_0_2_1/rgss-lib/dq/menu/Window_Status_Detail.rb <==
#==============================================================================
#  Window_Status_Detail
#------------------------------------------------------------------------------
# AN^[ڍ׃Xe[^X
# Copyright (C) 2005 fukuyama
#==============================================================================

module DQ

#----------------------------------------------------------------------------
#  ڍ׃Xe[^XEBhE
#----------------------------------------------------------------------------
class Window_Status_Detail < Window_Base
  #--------------------------------------------------------------------------
  #  IuWFNg
  #--------------------------------------------------------------------------
  def initialize(actor)
    @item_height = ITEM_HEIGHT
    super(0,0, 32 * 7 + 32, @item_height * 11 + 32)
    self.contents = Bitmap.new(self.width - 32, self.height - 32)
    @actor = actor
    @value_width = self.contents.text_size('00000').width
    refresh
  end
  #--------------------------------------------------------------------------
  #  AN^[̐ݒ
  #--------------------------------------------------------------------------
  def actor=(actor)
    if @actor != actor
      @actor = actor
      refresh
    end
  end
  #--------------------------------------------------------------------------
  #  tbV
  #--------------------------------------------------------------------------
  def draw_parameter(x,y,name,value)
    width = contents.width
    contents.font.color = system_color
    contents.draw_text(x,y,width - @value_width,@item_height,name + 'F',2)
    contents.font.color = normal_color
    contents.draw_text(x + width - @value_width,y,@value_width,@item_height,value.to_s,2)
    return x,(y+@item_height)
  end
  def refresh
    self.contents.clear
    return if @actor.nil?

    (x,y) = 0,0
    width = self.contents.width

    battler_image = RPG::Cache.battler(@actor.battler_name,@actor.battler_hue)
    self.contents.blt(x,y,battler_image,battler_image.rect,128)

    (x,y) = draw_parameter(x,y,$data_system.words.str,@actor.base_str)
    (x,y) = draw_parameter(x,y,$data_system.words.dex,@actor.base_dex)
    (x,y) = draw_parameter(x,y,$data_system.words.agi,@actor.base_agi)
    (x,y) = draw_parameter(x,y,$data_system.words.int,@actor.base_int)
    (x,y) = draw_parameter(x,y,'C',@actor.base_eva)
    (x,y) = draw_parameter(x,y,$data_system.words.atk,@actor.base_atk)
    (x,y) = draw_parameter(x,y,$data_system.words.pdef,@actor.base_pdef)
    (x,y) = draw_parameter(x,y,$data_system.words.mdef,@actor.base_mdef)
    (x,y) = draw_parameter(x,y,"#{$data_system.words.hp}",@actor.maxhp)
    (x,y) = draw_parameter(x,y,"#{$data_system.words.sp}",@actor.maxsp)
    rect = contents.text_size('ExF')
    contents.font.color = system_color
    contents.draw_text(x,y,rect.width,@item_height,'ExF',1)
    contents.font.color = normal_color
    contents.draw_text(x + rect.width,y,width - rect.width,@item_height,@actor.exp.to_s,2)
  end
end

end

==> DQScriptsDemo_0_3.zip: DQScriptsDemo_0_3/rgss-lib/dq/menu/Window_Status_Detail.rb <==
#==============================================================================
#  Window_Status_Detail
#------------------------------------------------------------------------------
# AN^[ڍ׃Xe[^X
# Copyright (C) 2005 fukuyama
#==============================================================================

module DQ

#----------------------------------------------------------------------------
#  ڍ׃Xe[^XEBhE
#----------------------------------------------------------------------------
class Window_Status_Detail < Window_Base
  #--------------------------------------------------------------------------
  #  IuWFNg
  #--------------------------------------------------------------------------
  def initialize(actor)
    @item_height = ITEM_HEIGHT
    super(0,0, 32 * 7 + 32, @item_height * 11 + 32)
    self.contents = Bitmap.new(self.width - 32, self.height - 32)
    @actor = actor
    @value_width = self.contents.text_size('00000').width
    refresh
  end
  #--------------------------------------------------------------------------
  #  AN^[̐ݒ
  #--------------------------------------------------------------------------
  def actor=(actor)
    if @actor != actor
      @actor = actor
      refresh
    end
  end
  #--------------------------------------------------------------------------
  #  tbV
  #--------------------------------------------------------------------------
  def draw_parameter(x,y,name,value)
    width = contents.width
    contents.font.color = system_color
    contents.draw_text(x,y,width - @value_width,@item_height,name + 'F',2)
    contents.font.color = normal_color
    contents.draw_text(x + width - @value_width,y,@value_width,@item_height,value.to_s,2)
    return x,(y+@item_height)
  end
  def refresh
    self.contents.clear
    return if @actor.nil?

    (x,y) = 0,0
    width = self.contents.width

    battler_image = RPG::Cache.battler(@actor.battler_name,@actor.battler_hue)
    self.contents.blt(x,y,battler_image,battler_image.rect,128)

    (x,y) = draw_parameter(x,y,$data_system.words.str,@actor.base_str)
    (x,y) = draw_parameter(x,y,$data_system.words.dex,@actor.base_dex)
    (x,y) = draw_parameter(x,y,$data_system.words.agi,@actor.base_agi)
    (x,y) = draw_parameter(x,y,$data_system.words.int,@actor.base_int)
    (x,y) = draw_parameter(x,y,'C',@actor.base_eva)
    (x,y) = draw_parameter(x,y,$data_system.words.atk,@actor.base_atk)
    (x,y) = draw_parameter(x,y,$data_system.words.pdef,@actor.base_pdef)
    (x,y) = draw_parameter(x,y,$data_system.words.mdef,@actor.base_mdef)
    (x,y) = draw_parameter(x,y,"ő#{$data_system.words.hp}",@actor.maxhp)
    (x,y) = draw_parameter(x,y,"ő#{$data_system.words.sp}",@actor.maxsp)
    rect = contents.text_size('ExF')
    contents.font.color = system_color
    contents.draw_text(x,y,rect.width,@item_height,'ExF',1)
    contents.font.color = normal_color
    contents.draw_text(x + rect.width,y,width - rect.width,@item_height,@actor.exp.to_s,2)
  end
end

end
